@@ -8,15 +8,9 @@ import numpy as np
 import datetime
 
 
-# ==============================================================================
-# ==============================================================================
-# ==============================================================================
-# ==============================================================================
-# ==============================================================================
-# ==============================================================================
-# ==============================================================================
-# ==============================================================================
+
 class Time():
+    
     """
     A class object to wait some time, get time, control time and such.
     Its methods (functions) are:
@@ -55,11 +49,15 @@ class Time():
     - pygame
     - time
     """
+    
     def __init__(self):
+        
         self.clock = builtin_time.perf_counter()
         self.pygame_clock = pygame.time.Clock()
 
+
     def reset(self):
+        
         """
         Reset the clock of the Time object.
 
@@ -89,10 +87,13 @@ class Time():
         - pygame
         - time
         """
+        
         self.clock = builtin_time.perf_counter()
         self.pygame_clock = pygame.time.Clock()
 
+
     def control(self, frequency=60):
+        
         """
         Control time. Must be placed in a while loop and, each time the program runs through it, checks if the time passed is less than a certain amount (the frequency, by default 60, so 1/60 seconds). If true, the program stops and wait what needed before continuing, so that each loop takes at least 1/frequency seconds to be complete.
 
@@ -123,9 +124,12 @@ class Time():
         - pygame
         - time
         """
+        
         self.pygame_clock.tick_busy_loop(frequency)
+        
 
     def get(self, reset=True):
+        
         """
         Get time since last initialisation / reset.
 
@@ -157,13 +161,19 @@ class Time():
         - pygame
         - time
         """
+        
         t = (builtin_time.perf_counter()-self.clock)*1000
 
         if reset is True:
             self.reset()
+            
         return(t)
 
-    def wait(self, time_to_wait, unit="ms", frequency=60, round_by_frame=True, skip=None):
+
+    def wait(self, 
+             time_to_wait, unit="ms", frequency=60, 
+             round_by_frame=True, skip=None):
+        
         """
         Wait some time.
 
@@ -213,27 +223,35 @@ class Time():
         - pygame
         - time
         """
+        
         t0 = builtin_time.perf_counter()
         if unit == "min":
             time_to_wait = time_to_wait * 60
             unit = "s"
+            
         if unit == "s":
             time_to_wait = time_to_wait * 1000
             unit = "ms"
+            
         if unit == "ms":
             if round_by_frame is True:
                 time_to_wait = round(time_to_wait / (1/frequency*1000))
                 time_to_wait = round(time_to_wait * (1/frequency*1000))
+                
         if unit == "frame":
             time_to_wait = time_to_wait * (1/frequency*1000)
 
         if skip is None:
             pygame.time.delay(time_to_wait)  # In milliseconds
+            
         else:
             response(allow=skip, time_max=time_to_wait)
+            
         return((builtin_time.perf_counter()-t0)*1000)
 
+
     def now(self):
+        
         """
         Returns current (absolute) date and time.
 
@@ -263,22 +281,18 @@ class Time():
         ----------
         - datetime
         """
+        
         return(datetime.datetime.now())
 
 # Initialize a Time() object.
 time = Time()
 
-# ==============================================================================
-# ==============================================================================
-# ==============================================================================
-# ==============================================================================
-# ==============================================================================
-# ==============================================================================
-# ==============================================================================
-# ==============================================================================
 
 
-def newpage(color_name="white", opacity=100, fade=False, fade_speed=60, fade_type="out", auto_refresh=True):
+def newpage(color_name="white", opacity=100, 
+            fade=False, fade_speed=60, fade_type="out", 
+            auto_refresh=True):
+    
     """
     Fill the background with a color.
 
@@ -316,6 +330,7 @@ def newpage(color_name="white", opacity=100, fade=False, fade_speed=60, fade_typ
     - pygame
     - time
     """
+    
     if color_name is not None:
         if fade is False:
             if opacity == 100:
@@ -323,41 +338,42 @@ def newpage(color_name="white", opacity=100, fade=False, fade_speed=60, fade_typ
                     screen.fill(color(color_name))
                 except:
                     print("NEUROPSYDIA ERROR: newpage(): wrong argument")
+                    
             else:
                 opacity = int(opacity * 255 / 100)
                 color_name = color(color_name) + (opacity,)
-                mask = pygame.Surface((screen_width, screen_height), pygame.SRCALPHA)  # per-pixel alpha
+                mask = pygame.Surface((screen_width, screen_height), 
+                                      pygame.SRCALPHA)  # per-pixel alpha
+                
                 mask.fill(color_name)  # notice the alpha value in the color
                 screen.blit(mask, (0, 0))
+                
             if auto_refresh is True:
                 refresh()
+                
         if fade is True:
             original_color_name = color_name
             clock = pygame.time.Clock()
+            
             for i in range(0, 40, 1):
                 clock.tick_busy_loop(fade_speed)
                 if fade_type == "out":
                     color_name = color(original_color_name) + (i,)
                 else:
                     color_name = color(original_color_name) + (255-i, )
-                mask = pygame.Surface((screen_width, screen_height), pygame.SRCALPHA)  # per-pixel alpha
+                    
+                mask = pygame.Surface((screen_width, screen_height), 
+                                      pygame.SRCALPHA)  # per-pixel alpha
+                
                 mask.fill(color_name)  # notice the alpha value in the color
                 screen.blit(mask, (0, 0))
                 refresh()
+                
             screen.fill(color(original_color_name))
 
 
-# ==============================================================================
-# ==============================================================================
-# ==============================================================================
-# ==============================================================================
-# ==============================================================================
-# ==============================================================================
-# ==============================================================================
-# ==============================================================================
-
-
 def refresh():
+    
     """
     Refresh / flip the screen: actually display things on screen.
 
@@ -381,16 +397,9 @@ def refresh():
 
     - pygame
     """
+    
     pygame.display.flip()
 
-# ==============================================================================
-# ==============================================================================
-# ==============================================================================
-# ==============================================================================
-# ==============================================================================
-# ==============================================================================
-# ==============================================================================
-# ==============================================================================
 keys = {
 "normal":
     {109: ',', 44: ';', 46: ':',47: '!', 97: 'q',
@@ -435,6 +444,7 @@ keys = {
 
 
 def wait_for_input(time_max=None):
+    
     """
     Low level input checker.
 
@@ -460,19 +470,25 @@ def wait_for_input(time_max=None):
     - pygame
     - time
     """
+    
     if pygame.event.get_blocked(pygame.KEYDOWN) is True:
         blocked = True
         pygame.event.set_allowed(pygame.KEYDOWN)
+        
     else:
         blocked = False
         pygame.event.set_allowed(pygame.KEYDOWN)
 
     time_out = False
     loop = True
+    
+    event_tc = []
     if time_max is None:
+
         while loop:
             for event in pygame.event.get():
-                #print(event)
+                
+                event_tc.append(event)
                 if event.type == pygame.KEYDOWN:
                     if pygame.key.get_mods() & pygame.KMOD_SHIFT:
                         modifier = "shift"
@@ -482,10 +498,14 @@ def wait_for_input(time_max=None):
                         modifier = "normal"
                     if event.key != pygame.K_RSHIFT and event.key != pygame.K_LSHIFT and event.key != pygame.K_RALT:
                         loop = False
+                        
     else:
+        
         local_time = Time()
         while loop and local_time.get(reset=False) < time_max:
             for event in pygame.event.get():
+                
+                event_tc.append(event)
                 if event.type == pygame.KEYDOWN:
                     if pygame.key.get_mods() & pygame.KMOD_SHIFT:
                         modifier = "shift"
@@ -495,10 +515,12 @@ def wait_for_input(time_max=None):
                         modifier = "normal"
                     if event.key != pygame.K_RSHIFT and event.key != pygame.K_LSHIFT and event.key != pygame.K_RALT:
                         loop = False
+                        
         if local_time.get(reset=False) > time_max:
             time_out = True
 
 
+    
     if blocked is True:
         pygame.event.set_blocked(pygame.KEYDOWN)
 
@@ -506,17 +528,20 @@ def wait_for_input(time_max=None):
         return("Time_Max_Exceeded")
     
     else:
+        while event_tc[-1].type != pygame.KEYDOWN:
+            event_tc.pop()
         try:
-            #print("USED")
-            print(event)
-            return(keys[modifier][event.key])
+
+            print(event_tc[-1])
+            return(keys[modifier][event_tc[-1].key])
+        
         except (KeyError, AttributeError):
-            #print("ERROR")
-            #print(event)
             return(event.key)
 
 
-def response(allow=None, enable_escape=True, time_max=None, get_RT=True):
+def response(allow=None, enable_escape=True, 
+             time_max=None, get_RT=True):
+    
     """
     Get a (keyboard, for now) response.
 
@@ -546,6 +571,7 @@ def response(allow=None, enable_escape=True, time_max=None, get_RT=True):
 
     - pygame
     """
+    
     local_time = Time()
     if allow is not None:
         if not isinstance(allow, list):
@@ -555,18 +581,21 @@ def response(allow=None, enable_escape=True, time_max=None, get_RT=True):
         pressed_key = wait_for_input(time_max=time_max)
         if pressed_key == "Time_Max_Exceeded":
             return("Time_Max_Exceeded", local_time.get())
+        
         if pressed_key == pygame.K_ESCAPE:
             if enable_escape is True:
                 if get_RT is True:
                     return("ESCAPE", local_time.get())
                 else:
                     return("ESCAPE")
+                
         elif allow is not None:
             if pressed_key in allow:
                 if get_RT is True:
                     return(pressed_key, local_time.get())
                 else:
                     return(pressed_key)
+                
         else:
             if get_RT is True:
                 return(pressed_key, local_time.get())
@@ -574,16 +603,8 @@ def response(allow=None, enable_escape=True, time_max=None, get_RT=True):
                 return(pressed_key)
 
 
-
-# ==============================================================================
-# ==============================================================================
-# ==============================================================================
-# ==============================================================================
-# ==============================================================================
-# ==============================================================================
-# ==============================================================================
-# ==============================================================================
 class Coordinates:
+    
     """
     A class object to go from pygame corrdinates system to neuropsydia's and vice versa.
 
@@ -611,7 +632,10 @@ class Coordinates:
     ----------
     - pygame
     """
-    def to_pygame(x=None, y=None, distance_x=None, distance_y=None):
+    
+    def to_pygame(x=None, y=None, 
+                  distance_x=None, distance_y=None):
+        
         """
         Convert coordinates from neuropsydia (-10:10) to pygame's system (in pixels).
 
@@ -641,22 +665,28 @@ class Coordinates:
         ----------
         - pygame
         """
+        
         if x != None and y == None:
             x = (x+10.0)/(10.0+10.0)*(screen_width-0.0)+0.0
             return(int(x))
+        
         if x == None and y != None:
             y = (-y+10.0)/(10.0+10.0)*(screen_height-0.0)+0.0
             return(int(y))
+        
         if x != None and y != None:
             x = (x+10.0)/(10.0+10.0)*(screen_width-0.0)+0.0
             y = (-y+10.0)/(10.0+10.0)*(screen_height-0.0)+0.0
             return(int(x),int(y))
+        
         if distance_x != None and distance_y is None:
             distance_x = (distance_x)/(10.0+10.0)*(screen_width-0.0)+0.0
             return(int(distance_x))
+        
         if distance_y != None and distance_x is None:
             distance_y = (-distance_y)/(10.0+10.0)*(screen_height-0.0)+0.0
             return(int(distance_y))
+        
         if distance_x != None and distance_y != None:
             distance_x = (distance_x)/(10.0+10.0)*(screen_width-0.0)+0.0
             distance_y = (-distance_y)/(10.0+10.0)*(screen_height-0.0)+0.0
@@ -664,6 +694,7 @@ class Coordinates:
 
 
     def from_pygame(x=None, y=None):
+        
         """
         Help incomplete, sorry.
 
@@ -687,18 +718,24 @@ class Coordinates:
         ----------
         - pygame
         """
+        
         if x != None and y == None:
             x =20*x/screen_width - 10
             return(x)
+        
         if x == None and y != None:
             y = -(20*y/screen_height) + 10
             return(y)
+        
         if x != None and y != None:
             x =20*x/screen_width - 10
             y = -(20*y/screen_height) + 10
             return(x, y)
 
-    def to_physical(distance_x=None, distance_y=None, monitor_diagnonal=monitor_diagonal, unit="cm"):
+
+    def to_physical(distance_x=None, distance_y=None, 
+                    monitor_diagnonal=monitor_diagonal, unit="cm"):
+        
         """
         Help incomplete, sorry.
 
@@ -736,14 +773,20 @@ class Coordinates:
         if distance_x != None and distance_y is None:
             distance_x = (distance_x)/(10.0+10.0)*(monitor_width-0.0)+0.0
             return(int(distance_x))
+        
         if distance_y != None and distance_x is None:
             distance_y = (distance_y)/(10.0+10.0)*(monitor_height-0.0)+0.0
             return(int(distance_y))
+        
         if distance_y != None and distance_x != None:
             distance_x = (distance_x)/(10.0+10.0)*(monitor_width-0.0)+0.0
             distance_y = (distance_y)/(10.0+10.0)*(monitor_height-0.0)+0.0
             return(distance_x, distance_y)
-    def from_physical(distance_x=None, distance_y=None, monitor_diagonal=monitor_diagonal, unit="cm"):
+        
+        
+    def from_physical(distance_x=None, distance_y=None, 
+                      monitor_diagonal=monitor_diagonal, unit="cm"):
+        
         """
         Help incomplete, sorry.
 
@@ -781,42 +824,38 @@ class Coordinates:
         if distance_x != None and distance_y is None:
             distance_x = (distance_x)*(10.0+10.0)/(monitor_width-0.0)+0.0
             return(int(distance_x))
+        
         if distance_y != None and distance_x is None:
             distance_y = (distance_y)*(10.0+10.0)/(monitor_height-0.0)+0.0
             return(int(distance_y))
+        
         if distance_y != None and distance_x != None:
             distance_x = (distance_x)/(10.0+10.0)*(monitor_width-0.0)+0.0
             distance_y = (distance_y)/(10.0+10.0)*(monitor_height-0.0)+0.0
             return(distance_x, distance_y)
-# ==============================================================================
-# ==============================================================================
-# ==============================================================================
-# ==============================================================================
-# ==============================================================================
-# ==============================================================================
-# ==============================================================================
-# ==============================================================================
+
+
 class Font_Cache_Init:
+    
     def __init__(self):
         self.cache = {}  #Initialize an empty cache
+        
     def get(self,font_path,size):
+        
         if not (font_path,int(size)) in self.cache:  #if not in cache,
             if os.path.exists(font_path):  #if the path leads to a font,
-                self.cache[font_path,int(size)] = pygame.font.Font(font_path, int(size))  #load this font
+                self.cache[font_path,int(size)] = pygame.font.Font(font_path, int(size))  
+              
             else:
                 self.cache[font_path,int(size)] = pygame.font.SysFont(font_path, int(size))  #load a system font
+        
         return(self.cache[font_path,int(size)])
+    
+    
 global Font
 Font = Font_Cache_Init()  #Create the font object that will update itself with the different loaded fonts
 
-# ==============================================================================
-# ==============================================================================
-# ==============================================================================
-# ==============================================================================
-# ==============================================================================
-# ==============================================================================
-# ==============================================================================
-# ==============================================================================
+
 color_list = {
 "white":(255,255,255),
 "w":(255,255,255),
@@ -849,7 +888,6 @@ color_list = {
 "darkgrey":(105,105,105),
 "bluegrey":(96,125,139),
 
-
 "pale_red":(239,154,154),
 "pale_pink":(244,143,177),
 "pale_purple":(206,147,216),
@@ -874,7 +912,9 @@ color_list = {
 "multi_shade":[(255,51,51),(255,51,255),(51,153,255),(51,255,51),(255,153,51)]
 }
 
+
 def color(color):
+    
     """
     Returns an RGB color tuple (or list) from its name.
 
@@ -903,24 +943,20 @@ def color(color):
     ----------
     None
     """
+    
     if isinstance(color,str):
         try:
             return(color_list[color])
         except:
             print("NEUROPSYDIA WARNING: color() was used, however the argument " + str(color) + " was not detected and might cause errors.")
             return(color)
+        
     else:
         return(color)
 
-# ==============================================================================
-# ==============================================================================
-# ==============================================================================
-# ==============================================================================
-# ==============================================================================
-# ==============================================================================
-# ==============================================================================
-# ==============================================================================
+
 def cursor(visible=True):
+    
     """
     Set the mouse cursor to visible or invisible.
 
@@ -949,4 +985,5 @@ def cursor(visible=True):
     ----------
     - pygame 1.9.2
     """
+    
     pygame.mouse.set_visible(visible)
